pub struct ActivityQueryResponse {
pub entries: Vec<ActivityEntry>,
pub cursor: Option<u64>,
pub head: ActivityCursor,
}Expand description
A page plus the current incarnation’s head at scan capture, even on an empty page. Subscribe from head to move from the scan to live entries without a gap.
Fields
entries: Vec<ActivityEntry>cursor: Option<u64>head: ActivityCursorImplementations