pub struct PendingReloadVerdict {
pub path: ReloadPathAgreement,
pub image: RunningImageAgreement,
}Expand description
Independent comparisons of configured path and running image at list time. An absent verdict means the daemon predates this field, not agreement.
Fields
path: ReloadPathAgreementimage: RunningImageAgreementTrait Implementations
Sourceimpl Clone for PendingReloadVerdict
impl Clone for PendingReloadVerdict
Sourceimpl Debug for PendingReloadVerdict
impl Debug for PendingReloadVerdict
Sourceimpl<'de> Deserialize<'de> for PendingReloadVerdict
impl<'de> Deserialize<'de> for PendingReloadVerdict
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for PendingReloadVerdict
impl PartialEq for PendingReloadVerdict
Sourceimpl Serialize for PendingReloadVerdict
impl Serialize for PendingReloadVerdict
impl StructuralPartialEq for PendingReloadVerdict